@@ -5,7 +5,7 @@ package Tk::Clock;
 use strict;
 use warnings;
 
-our $VERSION = "0.41";
+our $VERSION = "0.42";
 
 use Carp;
 
@@ -488,6 +488,12 @@ sub config {
 	croak "Bad hash";
 	}
 
+    # -anaScale -> anaScale
+    for (grep m/^-(\w+)$/ => keys %$conf) {
+	(my $attr = $_) =~ s/^-//;
+	$conf->{$attr} = delete $conf->{$_};
+	}
+
     my $data = $clock->privateData;
     my $pfmt = $] < 5.010 ? "s" : "s>";
     $attr_weight{$_} ||= unpack $pfmt, $_ for keys %def_config;
